package com.mortals.xhx.busiz.web;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.mortals.xhx.busiz.message.MessageService;
import com.mortals.xhx.busiz.req.MessageReq;
import com.mortals.xhx.busiz.rsp.ApiResp;
import com.mortals.xhx.busiz.rsp.MessageResp;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;


@RestController
@Slf4j
@RequestMapping("/api")
public class SecurityApiController {
    @Autowired
    private MessageService messageService;

    /**
     * 解密
     *
     * @param req
     * @return
     */
    @PostMapping("decrypt")
    public String decrypt(@RequestBody MessageReq req) {
        log.info("【解密】【请求体】-->  " + JSONObject.toJSONString(req));
        ApiResp<MessageReq> rsp = new ApiResp<>();
        rsp.setCode(ApiRespCodeEnum.SUCCESS.getValue());
        try {
            MessageReq messageReq = messageService.decryptMessage(req);
            rsp.setData(messageReq);
        } catch (Exception e) {
            log.error("接收数据失败", e);
            rsp.setCode(ApiRespCodeEnum.FAILED.getValue());
            rsp.setMsg(e.getMessage());
            return JSON.toJSONString(rsp);
        }
        log.info("响应【解密】【响应体】-->  " + JSONObject.toJSONString(rsp));
        return JSON.toJSONString(rsp);
    }


    /**
     * 批量解密
     *
     * @param reqList
     * @return
     */
    @PostMapping("decryptBatch")
    public String decryptBatch(@RequestBody List<MessageReq> reqList) {
        log.info("【批量解密】【请求体】-->  " + JSONObject.toJSONString(reqList));
        ApiResp<List<MessageReq>> rsp = new ApiResp<>();
        rsp.setCode(ApiRespCodeEnum.SUCCESS.getValue());
        try {
            List<MessageReq> respList=new ArrayList<>();
            reqList.stream().forEach(req->{
                MessageReq messageReq = messageService.decryptMessage(req);
                respList.add(messageReq);
            });
            rsp.setData(respList);
        } catch (Exception e) {
            log.error("接收数据失败", e);
            rsp.setCode(ApiRespCodeEnum.FAILED.getValue());
            rsp.setMsg(e.getMessage());
            return JSON.toJSONString(rsp);
        }
        log.info("响应【批量解密】【响应体】-->  " + JSONObject.toJSONString(rsp));
        return JSON.toJSONString(rsp);
    }


    /**
     * 加密
     *
     * @param req
     * @return
     */
    @PostMapping("encrypt")
    public String encrypt(MessageReq req) {
        log.info("【加密】【请求体】-->  " + JSONObject.toJSONString(req));
        ApiResp<MessageReq> rsp = new ApiResp<>();
        rsp.setCode(ApiRespCodeEnum.SUCCESS.getValue());

        try {
            MessageReq messageReq = messageService.encryptMessage(req);
            rsp.setData(messageReq);
        } catch (Exception e) {
            log.error("接收数据失败", e);
            rsp.setCode(ApiRespCodeEnum.FAILED.getValue());
            rsp.setMsg(e.getMessage());
            return JSON.toJSONString(rsp);
        }
        log.info("响应【加密】【响应体】-->  " + JSONObject.toJSONString(rsp));
        return JSON.toJSONString(rsp);
    }


    /**
     * 批量加密
     *
     * @param reqList
     * @return
     */
    @PostMapping("encryptBatch")
    public String encryptBatch(@RequestBody List<MessageReq> reqList) {
        log.info("【批量加密】【请求体】-->  " + JSONObject.toJSONString(reqList));
        ApiResp<List<MessageReq>> rsp = new ApiResp<>();
        rsp.setCode(ApiRespCodeEnum.SUCCESS.getValue());
        try {
            List<MessageReq> respList=new ArrayList<>();
            reqList.stream().forEach(req->{
                MessageReq messageReq = messageService.encryptMessage(req);
                respList.add(messageReq);
            });
            rsp.setData(respList);
        } catch (Exception e) {
            log.error("接收数据失败", e);
            rsp.setCode(ApiRespCodeEnum.FAILED.getValue());
            rsp.setMsg(e.getMessage());
            return JSON.toJSONString(rsp);
        }
        log.info("响应【批量加密】【响应体】-->  " + JSONObject.toJSONString(rsp));
        return JSON.toJSONString(rsp);
    }


    public static void main(String[] args) {

    }

}
